@@ -1,4 +1,4 @@
-/* GDM - The Gnome Display Manager
+/* GDM - The GNOME Display Manager
  * Copyright (C) 1998, 1999, 2000 Martin K. Petersen <mkp@mkp.net>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -17,7 +17,7 @@
  */
 
 #include "config.h"
-#include <libgnome/libgnome.h>
+#include <glib/gi18n.h>
 #include <unistd.h>
 #include <signal.h>
 #include <sys/stat.h>
@@ -32,11 +32,10 @@
 #include <errno.h>
 #include <syslog.h>
 
-#include <vicious.h>
-
 #include "gdm.h"
 #include "misc.h"
 #include "gdm-net.h"
+#include "gdmconfig.h"
 
 /* Kind of a weird setup, new connections whack old connections */
 #define MAX_CONNECTIONS 10
@@ -76,14 +75,14 @@ struct _GdmConnection {
 };
 
 static gboolean
-close_if_needed (GdmConnection *conn, GIOCondition cond)
+close_if_needed (GdmConnection *conn, GIOCondition cond, gboolean error)
 {
 	/* non-subconnections are never closed */
 	if (conn->parent == NULL)
 		return TRUE;
 
 	if (cond & G_IO_ERR ||
-	    cond & G_IO_HUP) {
+	    cond & G_IO_HUP || error) {
 		gdm_debug ("close_if_needed: Got HUP/ERR on %d", conn->fd);
 		conn->source = 0;
 		gdm_connection_close (conn);
@@ -103,11 +102,11 @@ gdm_connection_handler (GIOChannel *source,
 	size_t len;
 
 	if ( ! (cond & G_IO_IN)) 
-		return close_if_needed (conn, cond);
+		return close_if_needed (conn, cond, FALSE);
 
 	VE_IGNORE_EINTR (len = read (conn->fd, buf, sizeof (buf) -1));
 	if (len <= 0) {
-		return close_if_needed (conn, cond);
+		return close_if_needed (conn, cond, TRUE);
 	}
 
 	buf[len] = '\0';
@@ -141,7 +140,7 @@ gdm_connection_handler (GIOChannel *source,
 		}
 	}
 
-	return close_if_needed (conn, cond);
+	return close_if_needed (conn, cond, FALSE);
 }
 
 gboolean
