@@ -1,9 +1,22 @@
-#include "config.h"
+/* GDM - The GNOME Display Manager
+ * Copyright (C) 1998, 1999, 2000 Martin K. Petersen <mkp@mkp.net>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ */
 
-#include <vicious.h>
-#include "gdm.h"
-#include "misc.h"
-#include "getvt.h"
+#include "config.h"
 
 #include <stdio.h>
 #include <unistd.h>
@@ -11,12 +24,15 @@
 #include <string.h>
 #include <fcntl.h>
 #include <dirent.h>
+#include <errno.h>
 #include <sys/ioctl.h>
 #include <sys/stat.h>
 #include <sys/types.h>
 
-extern int GdmFirstVT;
-extern gboolean GdmVTAllocation;
+#include "gdm.h"
+#include "misc.h"
+#include "getvt.h"
+#include "gdmconfig.h"
 
 #if defined (__linux__) || defined (__FreeBSD__) || defined(__DragonFly__)
 
@@ -71,7 +87,8 @@ get_free_vt (int *vtfd)
 {
 	int fd, fdv;
 	int vtno;
-	GList *to_close_vts = NULL, *li;
+	unsigned short vtmask;
+	struct vt_stat vtstat;
 
 	*vtfd = -1;
 
@@ -86,7 +103,14 @@ get_free_vt (int *vtfd)
 	if (fd < 0)
 		return -1;
 
-	if ((ioctl(fd, VT_OPENQRY, &vtno) < 0) || (vtno == -1)) {
+	if (ioctl (fd, VT_GETSTATE, &vtstat) < 0) {
+		VE_IGNORE_EINTR (close (fd));
+		return -1;
+	}
+
+	for (vtno = gdm_get_value_int (GDM_KEY_FIRST_VT), vtmask = 1 << (vtno-1);
+			vtstat.v_state & vtmask; vtno++, vtmask <<= 1);
+	if (!vtmask) {
 		VE_IGNORE_EINTR (close (fd));
 		return -1;
 	}
@@ -96,46 +120,14 @@ get_free_vt (int *vtfd)
 		VE_IGNORE_EINTR (close (fd));
 		return -1;
 	}
-
-	while (vtno < GdmFirstVT) {
-		int oldvt = vtno;
-		to_close_vts = g_list_prepend (to_close_vts,
-					       GINT_TO_POINTER (fdv));
-
-#if defined (__linux__)
-		if ((ioctl(fd, VT_OPENQRY, &vtno) < 0) || (vtno == -1)) {
-#elif defined (__FreeBSD__) || defined(__DragonFly__)
-		if (ioctl(fd, VT_OPENQRY, &vtno) == -1) {
-#endif
-			vtno = -1;
-			goto cleanup;
-		}
-
-		if (oldvt == vtno) {
-			vtno = -1;
-			goto cleanup;
-		}
-
-		fdv = open_vt (vtno);
-		if (fdv < 0) {
-			vtno = -1;
-			goto cleanup;
-		}
-	}
-
 	*vtfd = fdv;
-
-cleanup:
-	for (li = to_close_vts; li != NULL; li = li->next) {
-		VE_IGNORE_EINTR (close (GPOINTER_TO_INT (li->data)));
-	}
 	return vtno;
 }
 
 char *
 gdm_get_empty_vt_argument (int *fd, int *vt)
 {
-	if ( ! GdmVTAllocation) {
+	if ( ! gdm_get_value_bool (GDM_KEY_VT_ALLOCATION)) {
 		*fd = -1;
 		return NULL;
 	}
