@@ -514,7 +514,7 @@ main (int argc, char *argv[])
 	gnome_config_push_prefix (config_prefix);
 	xdmcp_enabled = gnome_config_get_bool (GDM_KEY_XDMCP);
 	honor_indirect = gnome_config_get_bool (GDM_KEY_INDIRECT);
-	pidfile = gnome_config_get_string (GDM_KEY_PIDFILE);
+	pidfile = gnome_config_get_string (GDM_KEY_PID_FILE);
 	xnest = gnome_config_get_string (GDM_KEY_XNEST);
 	gnome_config_pop_prefix ();
 	g_free (config_file);
@@ -530,9 +530,7 @@ main (int argc, char *argv[])
 				       GTK_DIALOG_MODAL /* flags */,
 				       GTK_MESSAGE_ERROR,
 				       GTK_BUTTONS_OK,
-				       FALSE /* markup */,
 				       _("Xnest doesn't exist."),
-				       "%s",
 				       _("Please ask your system "
 					 "administrator "
 					 "to install it."));
@@ -558,9 +556,7 @@ main (int argc, char *argv[])
 				 GTK_DIALOG_MODAL /* flags */,
 				 GTK_MESSAGE_ERROR,
 				 GTK_BUTTONS_OK,
-				 FALSE /* markup */,
 				 _("Indirect XDMCP is not enabled"),
-				 "%s",
 				 _("Please ask your "
 				   "system administrator to enable "
 				   "this feature."));
@@ -578,9 +574,7 @@ main (int argc, char *argv[])
 				 GTK_DIALOG_MODAL /* flags */,
 				 GTK_MESSAGE_ERROR,
 				 GTK_BUTTONS_OK,
-				 FALSE /* markup */,
 				 _("XDMCP is not enabled"),
-				 "%s",
 				 _("Please ask your "
 				   "system administrator to enable "
 				   "this feature."));
@@ -613,9 +607,7 @@ main (int argc, char *argv[])
 				 GTK_DIALOG_MODAL /* flags */,
 				 GTK_MESSAGE_ERROR,
 				 GTK_BUTTONS_OK,
-				 FALSE /* markup */,
 				 _("GDM is not running"),
-				 "%s",
 				 _("Please ask your "
 				   "system administrator to start it."));
 			gtk_widget_show_all (d);
@@ -632,10 +624,9 @@ main (int argc, char *argv[])
 				       GTK_DIALOG_MODAL /* flags */,
 				       GTK_MESSAGE_ERROR,
 				       GTK_BUTTONS_OK,
-				       FALSE /* markup */,
 				       _("Could not find a free "
 					 "display number"),
-				       /* avoid warning */ "%s", "");
+				       "");
 		gtk_widget_show_all (d);
 		gtk_dialog_run (GTK_DIALOG (d));
 		gtk_widget_destroy (d);
