@@ -1,3 +1,21 @@
+/* GDM - The GNOME Display Manager
+ * Copyright (C) 1998, 1999, 2000 Martin K. Petersen <mkp@mkp.net>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ */
+
 #include "config.h"
 
 #include <gtk/gtk.h>
@@ -119,7 +137,7 @@ parse_button (xmlNodePtr node,
 	  g_set_error (error,
 		       GREETER_PARSER_ERROR,
 		       GREETER_PARSER_ERROR_BAD_SPEC,
-		       "bad button spec %s\n", prop);
+		       "bad button spec %s", prop);
 	  xmlFree (prop);
 	  return FALSE;
 	}
@@ -168,7 +186,7 @@ parse_pos (xmlNodePtr       node,
 	  g_set_error (error,
 		       GREETER_PARSER_ERROR,
 		       GREETER_PARSER_ERROR_BAD_SPEC,
-		       "Unknown anchor type %s\n", prop);
+		       "Unknown anchor type %s", prop);
 	  xmlFree (prop);
 	  return FALSE;
 	}
@@ -186,7 +204,7 @@ parse_pos (xmlNodePtr       node,
 	  g_set_error (error,
 		       GREETER_PARSER_ERROR,
 		       GREETER_PARSER_ERROR_BAD_SPEC,
-		       "Bad position specifier %s\n", prop);
+		       "Bad position specifier %s", prop);
 	  xmlFree (prop);
 	  return FALSE;
 	}
@@ -213,7 +231,7 @@ parse_pos (xmlNodePtr       node,
 	  g_set_error (error,
 		       GREETER_PARSER_ERROR,
 		       GREETER_PARSER_ERROR_BAD_SPEC,
-		       "Bad position specifier %s\n", prop);
+		       "Bad position specifier %s", prop);
 	  xmlFree (prop);
 	  return FALSE;
 	}
@@ -235,16 +253,18 @@ parse_pos (xmlNodePtr       node,
     {
       if (strcmp (prop, "box") == 0)
 	info->width_type = GREETER_ITEM_SIZE_BOX;
+      else if (strcmp (prop, "scale") == 0)
+       info->width_type = GREETER_ITEM_SIZE_SCALE;
       else
 	{
 	  info->width = g_ascii_strtod (prop, &p);
-      
+
 	  if ((char *)prop == p)
 	    {
 	      g_set_error (error,
 			   GREETER_PARSER_ERROR,
 			   GREETER_PARSER_ERROR_BAD_SPEC,
-			   "Bad size specifier %s\n", prop);
+			   "Bad size specifier %s", prop);
 	      xmlFree (prop);
 	      return FALSE;
 	    }
@@ -262,6 +282,8 @@ parse_pos (xmlNodePtr       node,
     {
       if (strcmp (prop, "box") == 0)
 	info->height_type = GREETER_ITEM_SIZE_BOX;
+      else if (strcmp (prop, "scale") == 0)
+       info->height_type = GREETER_ITEM_SIZE_SCALE;
       else
 	{
 	  info->height = g_ascii_strtod (prop, &p);
@@ -271,7 +293,7 @@ parse_pos (xmlNodePtr       node,
 	      g_set_error (error,
 			   GREETER_PARSER_ERROR,
 			   GREETER_PARSER_ERROR_BAD_SPEC,
-			   "Bad size specifier %s\n", prop);
+			   "Bad size specifier %s", prop);
 	      xmlFree (prop);
 	      return FALSE;
 	    }
@@ -300,7 +322,7 @@ parse_pos (xmlNodePtr       node,
 	  g_set_error (error,
 		       GREETER_PARSER_ERROR,
 		       GREETER_PARSER_ERROR_BAD_SPEC,
-		       "Bad expand spec %s\n", prop);
+		       "Bad expand spec %s", prop);
 	  xmlFree (prop);
 	  return FALSE;
 	}
@@ -439,7 +461,7 @@ parse_box (xmlNodePtr       node,
 	  g_set_error (error,
 		       GREETER_PARSER_ERROR,
 		       GREETER_PARSER_ERROR_BAD_SPEC,
-		       "Bad orientation %s\n", prop);
+		       "Bad orientation %s", prop);
 	  xmlFree (prop);
 	  return FALSE;
 	}
@@ -463,7 +485,7 @@ parse_box (xmlNodePtr       node,
 	  g_set_error (error,
 		       GREETER_PARSER_ERROR,
 		       GREETER_PARSER_ERROR_BAD_SPEC,
-		       "Bad homogenous spec %s\n", prop);
+		       "Bad homogenous spec %s", prop);
 	  xmlFree (prop);
 	  return FALSE;
 	}
@@ -482,7 +504,7 @@ parse_box (xmlNodePtr       node,
 	  g_set_error (error,
 		       GREETER_PARSER_ERROR,
 		       GREETER_PARSER_ERROR_BAD_SPEC,
-		       "Bad padding specification %s\n", prop);
+		       "Bad padding specification %s", prop);
 	  xmlFree (prop);
 	  return FALSE;
 	}
@@ -499,7 +521,7 @@ parse_box (xmlNodePtr       node,
 	  g_set_error (error,
 		       GREETER_PARSER_ERROR,
 		       GREETER_PARSER_ERROR_BAD_SPEC,
-		       "Bad padding specification %s\n", prop);
+		       "Bad padding specification %s", prop);
 	  xmlFree (prop);
 	  return FALSE;
 	}
@@ -516,7 +538,7 @@ parse_box (xmlNodePtr       node,
 	  g_set_error (error,
 		       GREETER_PARSER_ERROR,
 		       GREETER_PARSER_ERROR_BAD_SPEC,
-		       "Bad min-width specification %s\n", prop);
+		       "Bad min-width specification %s", prop);
 	  xmlFree (prop);
 	  return FALSE;
 	}
@@ -533,7 +555,7 @@ parse_box (xmlNodePtr       node,
 	  g_set_error (error,
 		       GREETER_PARSER_ERROR,
 		       GREETER_PARSER_ERROR_BAD_SPEC,
-		       "Bad min-height specification %s\n", prop);
+		       "Bad min-height specification %s", prop);
 	  xmlFree (prop);
 	  return FALSE;
 	}
@@ -550,7 +572,7 @@ parse_box (xmlNodePtr       node,
 	  g_set_error (error,
 		       GREETER_PARSER_ERROR,
 		       GREETER_PARSER_ERROR_BAD_SPEC,
-		       "Bad spacing specification %s\n", prop);
+		       "Bad spacing specification %s", prop);
 	  xmlFree (prop);
 	  return FALSE;
 	}
@@ -577,7 +599,7 @@ parse_color (const char *str,
       g_set_error (error,
 		   GREETER_PARSER_ERROR,
 		   GREETER_PARSER_ERROR_BAD_SPEC,
-		   "colors must start with #, %s is an invalid color\n", str);
+		   "colors must start with #, %s is an invalid color", str);
       return FALSE;
     }
   if G_UNLIKELY (strlen (str) != 7)
@@ -585,7 +607,7 @@ parse_color (const char *str,
       g_set_error (error,
 		   GREETER_PARSER_ERROR,
 		   GREETER_PARSER_ERROR_BAD_SPEC,
-		   "Colors must be on the format #xxxxxx, %s is an invalid color\n", str);
+		   "Colors must be on the format #xxxxxx, %s is an invalid color", str);
       return FALSE;
     }
 
@@ -600,10 +622,10 @@ parse_color (const char *str,
 }
 
 static gboolean
-parse_state_file (xmlNodePtr node,
-		  GreeterItemInfo  *info,
-		  GreeterItemState state,
-		  GError         **error)
+parse_state_file_pixmap (xmlNodePtr node,
+			 GreeterItemInfo  *info,
+			 GreeterItemState state,
+			 GError         **error)
 {
   xmlChar *prop;
   char *p;
@@ -614,9 +636,9 @@ parse_state_file (xmlNodePtr node,
   if (prop)
     {
       if (g_path_is_absolute (prop))
-	info->files[state] = g_strdup (prop);
+	info->data.pixmap.files[state] = g_strdup (prop);
       else
-	info->files[state] = g_build_filename (file_search_path,
+	info->data.pixmap.files[state] = g_build_filename (file_search_path,
 					       prop,
 					       NULL);
 	
@@ -626,37 +648,44 @@ parse_state_file (xmlNodePtr node,
   prop = xmlGetProp (node, "tint");
   if (prop)
     {
-      if (!parse_color (prop, &info->tints[state], error))
+      if (!parse_color (prop, &info->data.pixmap.tints[state], error))
 	return FALSE;
-      info->have_tint |= (1<<state);
+      info->data.pixmap.have_tint |= (1<<state);
       xmlFree (prop);
     }
 
   prop = xmlGetProp (node, "alpha");
   if (prop)
     {
-      info->alphas[state] = g_ascii_strtod (prop, &p);
+      double alpha = g_ascii_strtod (prop, &p);
       
       if G_UNLIKELY ((char *)prop == p)
 	{
 	  g_set_error (error,
 		       GREETER_PARSER_ERROR,
 		       GREETER_PARSER_ERROR_BAD_SPEC,
-		       "Bad alpha specifier format %s\n", prop);
+		       "Bad alpha specifier format %s", prop);
 	  xmlFree (prop);
 	  return FALSE;
 	}
       xmlFree (prop);
+
+      if (alpha >= 1.0)
+        info->data.pixmap.alphas[state] = 0xff;
+      else if (alpha < 0)
+        info->data.pixmap.alphas[state] = 0;
+      else
+        info->data.pixmap.alphas[state] = floor (alpha * 0xff);
     }
   
   return TRUE;
 }
 
 static gboolean
-parse_state_color (xmlNodePtr node,
-		   GreeterItemInfo  *info,
-		   GreeterItemState state,
-		   GError         **error)
+parse_state_color_rect (xmlNodePtr node,
+			GreeterItemInfo  *info,
+			GreeterItemState state,
+			GError         **error)
 {
   xmlChar *prop;
   char *p;
@@ -666,32 +695,77 @@ parse_state_color (xmlNodePtr node,
   prop = xmlGetProp (node, "color");
   if (prop)
     {
-      if G_UNLIKELY (!parse_color (prop, &info->colors[state], error))
+      if G_UNLIKELY (!parse_color (prop, &info->data.rect.colors[state], error))
 	return FALSE;
-      info->have_color |= (1<<state);
+      info->data.rect.have_color |= (1<<state);
       xmlFree (prop);
     }
 
   prop = xmlGetProp (node, "alpha");
   if (prop)
     {
-      info->alphas[state] = g_ascii_strtod (prop, &p);
+      double alpha = g_ascii_strtod (prop, &p);
       
       if G_UNLIKELY ((char *)prop == p)
 	{
 	  g_set_error (error,
 		       GREETER_PARSER_ERROR,
 		       GREETER_PARSER_ERROR_BAD_SPEC,
-		       "Bad alpha specifier format %s\n", prop);
+		       "Bad alpha specifier format %s", prop);
 	  xmlFree (prop);
 	  return FALSE;
 	}
       xmlFree (prop);
+
+      if (alpha >= 1.0)
+        info->data.rect.alphas[state] = 0xff;
+      else if (alpha < 0)
+        info->data.rect.alphas[state] = 0;
+      else
+        info->data.rect.alphas[state] = floor (alpha * 0xff);
     }
   
   return TRUE;
 }
 
+static gboolean
+parse_color_list (xmlNodePtr node,
+		      GreeterItemInfo  *info,
+		      GError         **error)
+{
+  xmlChar *prop;
+  char *p;
+  guint32 color;
+
+  prop = xmlGetProp (node, "iconcolor");
+  if (prop)
+    {
+      if G_UNLIKELY (!parse_color (prop, &color, error)) {
+        info->data.list.icon_color = NULL;
+	return FALSE;
+      } else {
+        info->data.list.icon_color = g_strdup (prop);
+      }
+
+      xmlFree (prop);
+    }
+
+  prop = xmlGetProp (node, "labelcolor");
+  if (prop)
+    {
+      if G_UNLIKELY (!parse_color (prop, &color, error)) {
+        info->data.list.label_color = NULL;
+	return FALSE;
+      } else {
+        info->data.list.label_color = g_strdup (prop);
+      }
+
+      xmlFree (prop);
+    }
+
+  return TRUE;
+}
+
 static gboolean
 parse_pixmap (xmlNodePtr        node,
 	      gboolean          svg,
@@ -707,17 +781,17 @@ parse_pixmap (xmlNodePtr        node,
     {
       if (strcmp (child->name, "normal") == 0)
 	{
-	  if G_UNLIKELY (!parse_state_file (child, info, GREETER_ITEM_STATE_NORMAL, error))
+	  if G_UNLIKELY (!parse_state_file_pixmap (child, info, GREETER_ITEM_STATE_NORMAL, error))
 	    return FALSE;
 	}
       else if (strcmp (child->name, "prelight") == 0)
 	{
-	  if G_UNLIKELY (!parse_state_file (child, info, GREETER_ITEM_STATE_PRELIGHT, error))
+	  if G_UNLIKELY (!parse_state_file_pixmap (child, info, GREETER_ITEM_STATE_PRELIGHT, error))
 	    return FALSE;
 	}
       else if (strcmp (child->name, "active") == 0)
 	{
-	  if G_UNLIKELY (!parse_state_file (child, info, GREETER_ITEM_STATE_ACTIVE, error))
+	  if G_UNLIKELY (!parse_state_file_pixmap (child, info, GREETER_ITEM_STATE_ACTIVE, error))
 	    return FALSE;
 	}
       else if (strcmp (child->name, "pos") == 0)
@@ -744,7 +818,7 @@ parse_pixmap (xmlNodePtr        node,
       child = child->next;
     }
 
-  if G_UNLIKELY (!info->files[GREETER_ITEM_STATE_NORMAL])
+  if G_UNLIKELY (!info->data.pixmap.files[GREETER_ITEM_STATE_NORMAL])
     {
       g_set_error (error,
 		   GREETER_PARSER_ERROR,
@@ -757,15 +831,15 @@ parse_pixmap (xmlNodePtr        node,
     {
       for (i = 0; i < GREETER_ITEM_STATE_MAX; i++)
 	{
-	  if (info->files[i] != NULL)
+	  if (info->data.pixmap.files[i] != NULL)
 	    {
-	      info->pixbufs[i] = load_pixbuf (info->files[i], error);
+	      info->data.pixmap.pixbufs[i] = load_pixbuf (info->data.pixmap.files[i], error);
 	      
-	      if G_UNLIKELY (info->pixbufs[i] == NULL)
+	      if G_UNLIKELY (info->data.pixmap.pixbufs[i] == NULL)
 		return FALSE;
 	    }
 	  else
-	    info->pixbufs[i] = NULL;
+	    info->data.pixmap.pixbufs[i] = NULL;
 	}
     }
 
@@ -786,17 +860,17 @@ parse_rect (xmlNodePtr node,
     {
       if (strcmp (child->name, "normal") == 0)
 	{
-	  if G_UNLIKELY (!parse_state_color (child, info, GREETER_ITEM_STATE_NORMAL, error))
+	  if G_UNLIKELY (!parse_state_color_rect (child, info, GREETER_ITEM_STATE_NORMAL, error))
 	    return FALSE;
 	}
       else if (strcmp (child->name, "prelight") == 0)
 	{
-	  if G_UNLIKELY (!parse_state_color (child, info, GREETER_ITEM_STATE_PRELIGHT, error))
+	  if G_UNLIKELY (!parse_state_color_rect (child, info, GREETER_ITEM_STATE_PRELIGHT, error))
 	    return FALSE;
 	}
       else if (strcmp (child->name, "active") == 0)
 	{
-	  if G_UNLIKELY (!parse_state_color (child, info, GREETER_ITEM_STATE_ACTIVE, error))
+	  if G_UNLIKELY (!parse_state_color_rect (child, info, GREETER_ITEM_STATE_ACTIVE, error))
 	    return FALSE;
 	}
       else if (strcmp (child->name, "pos") == 0)
@@ -825,15 +899,10 @@ parse_rect (xmlNodePtr node,
 
   for (i = 0; i < GREETER_ITEM_STATE_MAX; i++)
     {
-      if ( ! (info->have_color & (1<<i)))
+      if ( ! (info->data.rect.have_color & (1<<i)))
 	continue;
       
-      if (info->alphas[i] >= 1.0)
-	info->colors[i] = (info->colors[i] << 8) | 0xff;
-      else if (info->alphas[i] > 0)
-	info->colors[i] = (info->colors[i] << 8) | (guint) floor (0xff*info->alphas[i]);
-      else
-	info->colors[i] = 0;
+      info->data.rect.colors[i] = (info->data.rect.colors[i] << 8) | (guint) info->data.rect.alphas[i];
     }
   
   return TRUE;
@@ -854,13 +923,13 @@ parse_state_text (xmlNodePtr node,
   prop = xmlGetProp (node, "font");
   if (prop)
     {
-      info->fonts[state] = pango_font_description_from_string (prop);
-      if G_UNLIKELY (info->fonts[state] == NULL)
+      info->data.text.fonts[state] = pango_font_description_from_string (prop);
+      if G_UNLIKELY (info->data.text.fonts[state] == NULL)
 	{
 	  g_set_error (error,
 		       GREETER_PARSER_ERROR,
 		       GREETER_PARSER_ERROR_BAD_SPEC,
-		       "Bad font specification %s\n", prop);
+		       "Bad font specification %s", prop);
 	  xmlFree (prop);
 	  return FALSE;
 	}
@@ -870,27 +939,34 @@ parse_state_text (xmlNodePtr node,
   prop = xmlGetProp (node, "color");
   if (prop)
     {
-      if G_UNLIKELY (!parse_color (prop, &info->colors[state], error))
+      if G_UNLIKELY (!parse_color (prop, &info->data.text.colors[state], error))
 	return FALSE;
-      info->have_color |= (1<<state);
+      info->data.text.have_color |= (1<<state);
       xmlFree (prop);
    }
 
   prop = xmlGetProp (node, "alpha");
   if (prop)
     {
-      info->alphas[state] = g_ascii_strtod (prop, &p);
+      double alpha = g_ascii_strtod (prop, &p);
       
       if G_UNLIKELY ((char *)prop == p)
 	{
 	  g_set_error (error,
 		       GREETER_PARSER_ERROR,
 		       GREETER_PARSER_ERROR_BAD_SPEC,
-		       "Bad alpha specifier format %s\n", prop);
+		       "Bad alpha specifier format %s", prop);
 	  xmlFree (prop);
 	  return FALSE;
 	}
       xmlFree (prop);
+
+      if (alpha >= 1.0)
+        info->data.rect.alphas[state] = 0xff;
+      else if (alpha < 0)
+        info->data.rect.alphas[state] = 0;
+      else
+        info->data.rect.alphas[state] = floor (alpha * 0xff);
     }
   
   return TRUE;
@@ -998,7 +1074,7 @@ parse_stock (xmlNodePtr node,
       else if (g_ascii_strcasecmp (prop, "halt") == 0)
         {
 	  g_free (*translated_text);
-	  *translated_text = g_strdup (_("Shut_down"));
+	  *translated_text = g_strdup (_("Shut _Down"));
 	}
       else if (g_ascii_strcasecmp (prop, "suspend") == 0)
         {
@@ -1028,7 +1104,11 @@ parse_stock (xmlNodePtr node,
       else if (g_ascii_strcasecmp (prop, "timed-label") == 0)
         {
 	  g_free (*translated_text);
-	  *translated_text = g_strdup (_("User %s will login in %d seconds"));
+	  *translated_text = g_strdup (ngettext ("User %s will login in %d "
+				  		 "second",
+						 "User %s will login in %d "
+						 "seconds",
+						 1));
 	}
       else if (g_ascii_strcasecmp (prop, "welcome-label") == 0)
         {
@@ -1044,12 +1124,22 @@ parse_stock (xmlNodePtr node,
 	  g_free (*translated_text);
 	  *translated_text = g_strdup (_("Username:"));
 	}
+      else if (g_ascii_strcasecmp (prop, "ok") == 0)
+        {
+	  g_free (*translated_text);
+	  *translated_text = g_strdup (_("_OK"));
+	}
+      else if (g_ascii_strcasecmp (prop, "cancel") == 0)
+        {
+	  g_free (*translated_text);
+	  *translated_text = g_strdup (_("_Cancel"));
+	}
       else
         {
           g_set_error (error,
 		       GREETER_PARSER_ERROR,
 		       GREETER_PARSER_ERROR_BAD_SPEC,
-		       "Bad stock label type\n");
+		       "Bad stock label type");
 	  xmlFree (prop);
 	  return FALSE;
 	}
@@ -1066,11 +1156,83 @@ parse_stock (xmlNodePtr node,
       g_set_error (error,
 		   GREETER_PARSER_ERROR,
 		   GREETER_PARSER_ERROR_BAD_SPEC,
-		   "Stock type not specified\n");
+		   "Stock type not specified");
       return FALSE;
     }
 }
 
+static void
+do_font_size_reduction (GreeterItemInfo *info)
+{
+  double size_reduction = 1.0;
+  int i;
+
+  if (gdm_wm_screen.width <= 800 &&
+      gdm_wm_screen.width > 640)
+    size_reduction = PANGO_SCALE_SMALL;
+  else if (gdm_wm_screen.width <= 640)
+    size_reduction = PANGO_SCALE_X_SMALL;
+
+  if (size_reduction < 0.99)
+    {
+      for (i = 0; i < GREETER_ITEM_STATE_MAX; i++)
+        {
+          if (info->data.text.fonts[i] != NULL)
+	    {
+	      int old_size = pango_font_description_get_size (info->data.text.fonts[i]);
+	      pango_font_description_set_size (info->data.text.fonts[i], old_size * size_reduction);
+	    }
+	}
+    }
+}
+
+
+static gboolean
+parse_label_pos_extras (xmlNodePtr       node,
+			GreeterItemInfo *info,
+			GError         **error)
+{
+  xmlChar *prop;
+  char *p;
+  
+  prop = xmlGetProp (node, "max-width");
+  if (prop)
+    {
+      info->data.text.max_width = g_ascii_strtod (prop, &p);
+      
+      if G_UNLIKELY ((char *)prop == p)
+	{
+	  g_set_error (error,
+		       GREETER_PARSER_ERROR,
+		       GREETER_PARSER_ERROR_BAD_SPEC,
+		       "Bad max-width specification %s", prop);
+	  xmlFree (prop);
+	  return FALSE;
+	}
+      xmlFree (prop);
+    }
+
+  prop = xmlGetProp (node, "max-screen-percent-width");
+  if (prop)
+    {
+      info->data.text.max_screen_percent_width = g_ascii_strtod (prop, &p);
+      
+      if G_UNLIKELY ((char *)prop == p)
+	{
+	  g_set_error (error,
+		       GREETER_PARSER_ERROR,
+		       GREETER_PARSER_ERROR_BAD_SPEC,
+		       "Bad max-screen-percent-width specification %s", prop);
+	  xmlFree (prop);
+	  return FALSE;
+	}
+      xmlFree (prop);
+    }
+
+  return TRUE;
+}
+  
+
 static gboolean
 parse_label (xmlNodePtr        node,
 	     GreeterItemInfo  *info,
@@ -1078,12 +1240,11 @@ parse_label (xmlNodePtr        node,
 {
   xmlNodePtr child;
   int i;
-  double size_reduction = 1.0;
   char *translated_text;
   gint translation_score = 1000;
   
   translated_text = NULL;
-  
+
   child = node->children;
   while (child)
     {
@@ -1106,6 +1267,8 @@ parse_label (xmlNodePtr        node,
 	{
 	  if G_UNLIKELY (!parse_pos (child, info, error))
 	    return FALSE;
+	  if G_UNLIKELY (!parse_label_pos_extras (child, info, error))
+	    return FALSE;
 	}
       else if (child->type == XML_ELEMENT_NODE &&
 	       strcmp (child->name, "text") == 0)
@@ -1156,39 +1319,18 @@ parse_label (xmlNodePtr        node,
 
   for (i = 0; i < GREETER_ITEM_STATE_MAX; i++)
     {
-      if ( ! (info->have_color & (1<<i)))
+      if ( ! (info->data.text.have_color & (1<<i)))
 	continue;
       
-      if (info->alphas[i] >= 1.0)
-	info->colors[i] = (info->colors[i] << 8) | 0xff;
-      else if (info->alphas[i] > 0)
-	info->colors[i] = (info->colors[i] << 8) | (guint) floor (0xff*info->alphas[i]);
-      else
-	info->colors[i] = 0;
+      info->data.text.colors[i] = (info->data.text.colors[i] << 8) | (guint) info->data.text.alphas[i];
     }
   
-  if (info->fonts[GREETER_ITEM_STATE_NORMAL] == NULL)
-    info->fonts[GREETER_ITEM_STATE_NORMAL] = pango_font_description_from_string ("Sans");
+  if (info->data.text.fonts[GREETER_ITEM_STATE_NORMAL] == NULL)
+    info->data.text.fonts[GREETER_ITEM_STATE_NORMAL] = pango_font_description_from_string ("Sans");
 
-  if (gdm_wm_screen.width <= 800 &&
-      gdm_wm_screen.width > 640)
-    size_reduction = PANGO_SCALE_SMALL;
-  else if (gdm_wm_screen.width <= 640)
-    size_reduction = PANGO_SCALE_X_SMALL;
+  do_font_size_reduction (info);
 
-  if (size_reduction < 0.99)
-    {
-      for (i = 0; i < GREETER_ITEM_STATE_MAX; i++)
-        {
-          if (info->fonts[i] != NULL)
-	    {
-	      int old_size = pango_font_description_get_size (info->fonts[i]);
-	      pango_font_description_set_size (info->fonts[i], old_size * size_reduction);
-	    }
-	}
-    }
-
-  info->orig_text = translated_text;
+  info->data.text.orig_text = translated_text;
   
   return TRUE;
 }
@@ -1250,7 +1392,7 @@ parse_listitem (xmlNodePtr        node,
     }
   li->text = translated_text;
 
-  info->list_items = g_list_append (info->list_items, li);
+  info->data.list.items = g_list_append (info->data.list.items, li);
 
   return TRUE;
 }
@@ -1265,6 +1407,11 @@ parse_list (xmlNodePtr        node,
   child = node->children;
   while (child)
     {
+      if (strcmp (child->name, "color") == 0)
+	{
+	  if G_UNLIKELY (!parse_color_list (child, info, error))
+	    return FALSE;
+	}
       if (strcmp (child->name, "pos") == 0)
 	{
 	  if G_UNLIKELY (!parse_pos (child, info, error))
@@ -1293,7 +1440,7 @@ parse_list (xmlNodePtr        node,
       child = child->next;
     }
 
-  if (info->list_items != NULL) {
+  if (info->data.list.items != NULL) {
     if G_UNLIKELY (strcmp (info->id, "userlist") == 0) {
       g_set_error (error,
 		   GREETER_PARSER_ERROR,
@@ -1317,7 +1464,12 @@ parse_entry (xmlNodePtr        node,
   child = node->children;
   while (child)
     {
-      if (strcmp (child->name, "pos") == 0)
+      if (strcmp (child->name, "normal") == 0)
+	{
+	  if G_UNLIKELY (!parse_state_text (child, info, GREETER_ITEM_STATE_NORMAL, error))
+	    return FALSE;
+	}
+      else if (strcmp (child->name, "pos") == 0)
 	{
 	  if G_UNLIKELY (!parse_pos (child, info, error))
 	    return FALSE;
@@ -1340,6 +1492,8 @@ parse_entry (xmlNodePtr        node,
       child = child->next;
     }
 
+  do_font_size_reduction (info);
+
   return TRUE;
 }
 
