@@ -60,9 +60,8 @@ bin_exists (const char *command)
 static void
 query_greeter_restart_handler (void)
 {
-	if (gdm_common_query (_("Are you sure you want to restart the computer?"),
-			   FALSE /* markup */, _("_Reboot"), NULL,
-			   TRUE) == GTK_RESPONSE_YES) {
+	if (gdm_common_warn (_("Are you sure you want to restart the computer?"), "",
+			     _("_Reboot"), NULL, TRUE) == GTK_RESPONSE_YES) {
 		closelog();
 		
 		_exit (DISPLAY_REBOOT);
@@ -73,9 +72,8 @@ query_greeter_restart_handler (void)
 static void
 query_greeter_halt_handler (void)
 {
-	if (gdm_common_query (_("Are you sure you want to shut down the computer?"),
-			   FALSE /* markup */, _("Shut _Down"), NULL,
-			   TRUE) == GTK_RESPONSE_YES) {
+	if (gdm_common_warn (_("Are you sure you want to shut down the computer?"), "",
+			     _("Shut _Down"), NULL, TRUE) == GTK_RESPONSE_YES) {
 		closelog();
 
 		_exit (DISPLAY_HALT);
@@ -85,9 +83,8 @@ query_greeter_halt_handler (void)
 static void
 query_greeter_suspend_handler (void)
 {
-	if (gdm_common_query (_("Are you sure you want to suspend the computer?"),
-			   FALSE /* markup */, _("_Suspend"), NULL,
-			   TRUE) == GTK_RESPONSE_YES) {
+	if (gdm_common_warn (_("Are you sure you want to suspend the computer?"), "",
+			     _("_Suspend"), NULL, TRUE) == GTK_RESPONSE_YES) {
 		/* suspend interruption */
 		printf ("%c%c%c\n", STX, BEL, GDM_INTERRUPT_SUSPEND);
 		fflush (stdout);
@@ -119,11 +116,6 @@ greeter_suspend_handler (void)
 static void
 greeter_config_handler (void)
 {
-        greeter_item_ulist_disable ();
-
-        /* Make sure to unselect the user */
-        greeter_item_ulist_unset_selected_user ();
-
 	/* we should be now fine for focusing new windows */
 	gdm_wm_focus_new_windows (TRUE);
 
