@@ -173,6 +173,7 @@ glade_helper_bad_interface (const char *filename, const char *widget,
 	char *typestring;
 	const char *typename;
 	char *tmp;
+	char *msg;
 
 	if (type != 0)
 		typename = g_type_name (type);
@@ -186,27 +187,29 @@ glade_helper_bad_interface (const char *filename, const char *widget,
 
 	tmp = ve_filename_to_utf8 (filename);
 	
+	msg = g_strdup_printf (_("An error occurred while loading user "
+				 "interface element %s%s from file %s.  "
+				 "Possibly the glade interface description was "
+				 "corrupted.  "
+				 "%s cannot continue and will exit now.  "
+				 "You should check your "
+				 "installation of %s or reinstall %s."),
+				widget,
+				typestring,
+				tmp,
+				PACKAGE,
+				PACKAGE,
+				PACKAGE);
+	
 	dlg = ve_hig_dialog_new (NULL /* parent */,
 				 0 /* flags */,
 				 GTK_MESSAGE_ERROR,
 				 GTK_BUTTONS_OK,
-				 FALSE /* markup */,
 				 _("Cannot load user interface"),
-				 _("An error occurred while loading user "
-				   "interface element %s%s from file %s.  "
-				   "Possibly the glade interface description was "
-				   "corrupted.  "
-				   "%s cannot continue and will exit now.  "
-				   "You should check your "
-				   "installation of %s or reinstall %s."),
-				 widget,
-				 typestring,
-				 tmp,
-				 PACKAGE,
-				 PACKAGE,
-				 PACKAGE);
+				 msg);
 
 	g_free (typestring);
+	g_free (msg);
 
 	g_warning (_("Glade file is on crack! Make sure the correct "
 		     "file is installed!\nfile: %s widget: %s"),
@@ -226,6 +229,7 @@ glade_helper_bad_columns (const char *filename, const char *widget,
 	char *typestring;
 	const char *typename;
 	char *tmp;
+	char *msg;
 
 	if (type != 0)
 		typename = g_type_name (type);
@@ -239,31 +243,24 @@ glade_helper_bad_columns (const char *filename, const char *widget,
 
 	tmp = ve_filename_to_utf8 (filename);
 	
-	dlg = ve_hig_dialog_new (NULL /* parent */,
-				 0 /* flags */,
-				 GTK_MESSAGE_ERROR,
-				 GTK_BUTTONS_OK,
-				 FALSE /* markup */,
-				 _("Cannot load user interface"),
-				 ngettext ("An error occurred while loading the "
-					   "user interface element %s%s from "
-					   "file %s. CList type widget should "
-					   "have %d column. Possibly the glade "
-					   "interface description was "
-					   "corrupted. %s cannot continue and "
-					   "will exit now. You should check "
-					   "your installation of %s or "
-					   "reinstall %s.",
-					   "An error occurred while loading the "
-					   "user interface element %s%s from "
-					   "file %s. CList type widget should "
-					   "have %d columns. Possibly the "
-					   "glade interface description was "
-					   "corrupted. %s cannot continue and "
-					   "will exit now. You should check "
-					   "your installation of %s or "
-					   "reinstall %s.",
-					   columns),
+	msg = g_strdup_printf (ngettext ("An error occurred while loading the "
+	                                 "user interface element %s%s from "
+	                                 "file %s. CList type widget should "
+	                                 "have %d column. Possibly the glade "
+	                                 "interface description was "
+	                                 "corrupted. %s cannot continue and "
+	                                 "will exit now. You should check "
+	                                 "your installation of %s or "
+	                                 "reinstall %s.",
+	                                 "An error occurred while loading the "
+	                                 "user interface element %s%s from "
+	                                 "file %s. CList type widget should "
+	                                 "have %d columns. Possibly the "
+	                                 "glade interface description was "
+	                                 "corrupted. %s cannot continue and "
+	                                 "will exit now. You should check "
+	                                 "your installation of %s or "
+	                                 "reinstall %s.", columns),
 				 widget,
 				 typestring,
 				 tmp,
@@ -272,7 +269,15 @@ glade_helper_bad_columns (const char *filename, const char *widget,
 				 PACKAGE,
 				 PACKAGE);
 
+	dlg = ve_hig_dialog_new (NULL /* parent */,
+				 0 /* flags */,
+				 GTK_MESSAGE_ERROR,
+				 GTK_BUTTONS_OK,
+				 _("Cannot load user interface"),
+				 msg);
+
 	g_free (typestring);
+	g_free (msg);
 
 	g_warning (_("Glade file is on crack! Make sure the correct "
 		     "file is installed!\nfile: %s widget: %s "
@@ -290,31 +295,34 @@ glade_helper_no_interface (const char *filename)
 {
 	GtkWidget *dlg;
 	char *tmp;
+	char *msg;
 
 	tmp = ve_filename_to_utf8 (filename);
 	
+	msg = g_strdup_printf (_("An error occurred while loading the user "
+	                         "interface from file %s.  "
+	                         "Possibly the glade interface description was "
+	                         "not found.  "
+	                         "%s cannot continue and will exit now.  "
+	                         "You should check your "
+	                         "installation of %s or reinstall %s."),
+	                         tmp,
+	                       PACKAGE,
+	                       PACKAGE,
+	                       PACKAGE);
+	
 	dlg = ve_hig_dialog_new (NULL /* parent */,
 				 0 /* flags */,
 				 GTK_MESSAGE_ERROR,
 				 GTK_BUTTONS_OK,
-				 FALSE /* markup */,
 				 _("Cannot load user interface"),
-				 _("An error occurred while loading the user "
-				   "interface from file %s.  "
-				   "Possibly the glade interface description was "
-				   "not found.  "
-				   "%s cannot continue and will exit now.  "
-				   "You should check your "
-				   "installation of %s or reinstall %s."),
-				 tmp,
-				 PACKAGE,
-				 PACKAGE,
-				 PACKAGE);
+				 msg);
 	gtk_dialog_set_has_separator (GTK_DIALOG (dlg), FALSE);
 	g_warning (_("No interface could be loaded. This is BAD! (file: %s)"),
 		   tmp);
 
 	g_free (tmp);
+	g_free (msg);
 
 	gtk_dialog_run (GTK_DIALOG (dlg));
 	gtk_widget_destroy (dlg);
@@ -390,7 +398,7 @@ glade_helper_tagify_label (GladeXML *xml,
 					    GTK_TYPE_LABEL);
 		exit (1);
 	}
-	lbl = gtk_label_get_text (GTK_LABEL (label));
+	lbl = gtk_label_get_label (GTK_LABEL (label));
 	s = g_strdup_printf ("<%s>%s</%s>", tag, lbl, tag);
 	gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
 	gtk_label_set_label (GTK_LABEL (label), s);
